@@ -9,7 +9,7 @@ use Data::Printer;
 
 with 'WebService::Client';
 # ABSTRACT: Perl 5 interface to Pixabay API.
-our $VERSION = '0.0.2'; # VERSION
+our $VERSION = '0.0.3'; # VERSION
 
 has api_key =>
 (
@@ -76,7 +76,7 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -99,7 +99,7 @@ version 0.0.2
 	# example custom image search
 	my $nis = $pix->image_search(
 		q => 'cats dog',
-		en => 'es',
+		lang => 'es',
 		response_group => 'high_resolution',
 		image_type => 'illustration',
 		category => 'animals',
@@ -113,7 +113,7 @@ version 0.0.2
 	# example custom video search
 	my $nvs = $pix->video_search(
 		q => 'tree',
-		en = 'en',
+		lang => 'en',
 		pretty => 'false',
 		page => 3,
 		order => 'popular'
@@ -126,11 +126,17 @@ version 0.0.2
 =head1 SEE ALSO
 
 L<Pixabay API documentations|https://pixabay.com/api/docs>
+
 L<Moo>
+
 L<Function::Parameters>
+
 L<Test::More>
+
 L<WebService::Client>
+
 L<LWP::Online>
+
 L<Data::Printer>
 
 =head1 AUTHOR
